@@ -184,8 +184,7 @@ main (int argc, char **argv)
 {
 	GError *error = NULL;
 	GOptionContext *ctx;
-
-	g_setenv ("GSETTINGS_BACKEND", "gconf", FALSE);
+	GtkSettings *settings;
 
 	if (!g_thread_supported ())
 		g_thread_init (NULL);
@@ -249,6 +248,11 @@ main (int argc, char **argv)
 	gtk_window_set_default_icon_name ("eog");
 	g_set_application_name (_("Eye of GNOME Image Viewer"));
 
+	settings = gtk_settings_get_default ();
+	g_object_set (G_OBJECT (settings),
+	              "gtk-application-prefer-dark-theme", TRUE,
+	              NULL);
+
 	load_files ();
 
 	gdk_threads_enter ();
